<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 * @return array An array of default values
 */

function elead_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$elead_pro_default_options = array(

		// Theme Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		'enable_sticky_menu'			=> false,
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'fa-spinner',
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'read_more_text'		        => esc_html__( 'Read More', 'elead-pro' ),
		'breadcrumb_enable'         	=> true,
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',
		'copyright_text'                => sprintf( _x( 'Copyright &copy; %1$s %2$s. All Rights Reserved', '1: Year, 2: Site Title with home URL', 'elead-pro' ), '[the-year]', '[site-link]' ),
		'powered_by'                    =>  esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'elead-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( $theme_data->get( 'Author' ) ) .'</a>',
		'scroll_top_visible'        	=> true,
		'reset_options'      			=> false,
		'enable_frontpage_content' 		=> true,
		'theme_color'					=> 'red',

		//single post options
		'tags_enable'					=> true,
		'author_name_enable'			=> true,
		'enable_date'					=> true,
		'comments_enable'				=> true,
		'author_box_enable'				=> true,
		'post_navigation_enable'		=> true,
		
		//blog page options
		'blog_section_title'			=> esc_html__( 'Welcome to Our Blog', 'elead-pro' ),
		'blog_section_subtitle'			=> esc_html__( 'Complete Articles', 'elead-pro' ),
		'category_enable'				=> true,
		'enable_blog_date'				=> true,

		// Headline Section
		'headline_enable'				=> true,
		'headline_label'				=> esc_html__( 'News', 'elead-pro' ),
		'headline_content_type'			=> 'demo',
		'headline_content_count'		=> 6,
		'headline_social_enable'		=> true,
		'headline_social_link_1'		=> esc_url( 'http://facebook.com' ),
		'headline_social_link_2'		=> esc_url( 'http://twitter.com' ),
		'headline_social_link_3'		=> esc_url( 'http://instagram.com' ),
		'headline_social_link_4'		=> esc_url( 'http://plus.google.com' ),
		'headline_social_link_5'		=> esc_url( 'http://pinterest.com' ),

		// Slider Section
		'slider_enable'					=> true,
		'slider_effect'					=> 'fade',
		'slider_transition_duration'	=> '1000',
		'enable_slider_controls'		=> true,
		'enable_slider_pager'			=> true,
		'enable_slider_dragable'		=> true,
		'slider_autoplay'				=> true,
		'enable_infinite_slider'		=> true,
		'slider_pause_on_hover'			=> true,
		'slider_content_type'			=> 'demo',
		'no_of_slider'					=> 3,
		'slider_btn_label'				=> esc_html__( 'Read More', 'elead-pro' ),

		// About Section
		'about_enable'					=> true,
		'about_content_type'			=> 'demo',
		'about_image_type'				=> 'multiple-image',
		'about_custom_title'			=> esc_html__( 'About Us', 'elead-pro' ),
		'about_custom_url'				=> esc_html__( '#', 'elead-pro' ),
		'about_custom_subtitle'			=> esc_html__( 'Know Who We Are', 'elead-pro' ),
		'about_custom_excerpt'			=> esc_html__( 'Proin urna nisl, egestas eget varius vel, commodo mattis elit. Nulla dapibus leo in nisi porttitor, sed dapibus risus porta. Etiam id aliquam massa. Fusce dignissim ex sollicitudin, consequat odio a, rhoncus massa. Vivamus venenatis pulvinar cursus habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas.', 'elead-pro' ),
		'about_custom_image_1'			=> get_template_directory_uri() . '/assets/uploads/about-01.jpg',
		'about_custom_image_2'			=> get_template_directory_uri() . '/assets/uploads/about-02.jpg',
		'about_custom_image_3'			=> get_template_directory_uri() . '/assets/uploads/about-03.jpg',

		// Service Section
		'service_enable'				=> true,
		'service_section_title'			=> esc_html__( 'We are best for you', 'elead-pro' ),
		'service_section_subtitle'		=> esc_html__( 'Our Quality Services', 'elead-pro' ),
		'service_content_type'			=> 'demo',

		// Courses Section
		'courses_enable'				=> true,
		'courses_content_type'			=> 'demo',
		'courses_title'					=> esc_html__( 'Learn With Us', 'elead-pro' ),
		'courses_sub_title'				=> esc_html__( 'Our Courses', 'elead-pro' ),
		'no_of_courses'					=> 3,
		'courses_custom_btn_label'		=> esc_html__( 'View All Courses', 'elead-pro' ),
		'courses_custom_btn_url'		=> esc_html__( '#', 'elead-pro' ),

		// latest news
		'latest_news_enable'			=> true,
		'latest_news_count'				=> 4,
		'latest_news_title'				=> esc_html__( 'Happening Around Us', 'elead-pro' ),
		'latest_news_subtitle'			=> esc_html__( 'Latest News & Events', 'elead-pro' ),
		'latest_news_content_type'		=> 'demo',
		'latest_news_custom_btn_label'	=> esc_html__( 'View All News & Events', 'elead-pro' ),
		'latest_news_custom_btn_url'	=> esc_html__( '#', 'elead-pro' ),
		
		// call to action section
		'call_to_action_enable'			=> true,
		'call_to_action_title'			=> esc_html__( 'Choose Your Own Path', 'elead-pro' ),
		'call_to_action_sub_title'		=> esc_html__( 'Build your career with us', 'elead-pro' ),
		'call_to_action_btn_label_1'	=> esc_html__( 'Start Learning', 'elead-pro' ),
		'call_to_action_btn_label_2'	=> esc_html__( 'Find Courses', 'elead-pro' ),
		'call_to_action_btn_url_1'		=> '#',
		'call_to_action_btn_url_2'		=> '#',

		// counter
		'counter_enable'				=> true,
		'counter_icon_1'				=> 'fa-book',	
		'counter_icon_2'				=> 'fa-users',	
		'counter_icon_3'				=> 'fa-graduation-cap',	
		'counter_icon_4'				=> 'fa-calendar',
		'counter_count_1'				=> esc_html__( '28', 'elead-pro' ),	
		'counter_count_2'				=> esc_html__( '20', 'elead-pro' ),		
		'counter_count_3'				=> esc_html__( '150', 'elead-pro' ),	
		'counter_count_4'				=> esc_html__( '89', 'elead-pro' ),	
		'counter_title_1'				=> esc_html__( 'Our Courses', 'elead-pro' ),	
		'counter_title_2'				=> esc_html__( 'No. of Staffs', 'elead-pro' ),		
		'counter_title_3'				=> esc_html__( 'Graduates', 'elead-pro' ),	
		'counter_title_4'				=> esc_html__( 'Successful Events', 'elead-pro' ),

		// team
		'team_enable'					=> true,
		'team_section_title'			=> esc_html__( 'Professional Teachers', 'elead-pro' ),
		'team_section_subtitle'			=> esc_html__( 'Our Qualified Manpower', 'elead-pro' ),
		'team_section_excerpt'			=> esc_html__( 'Pellentesque dui lectus, elementum non consectetur sed, lobortis sed dui. Ut facilisis metus eu vulputate fermentum. Phasellus nulla velit, lobortis ac faucibus id, maximus eu sapien.', 'elead-pro' ),
		'team_content_type'				=> 'demo',
		'team_custom_btn_label'			=> esc_html__( 'View All Teachers', 'elead-pro' ),
		'team_custom_btn_url'			=> esc_html__( '#', 'elead-pro' ),


		// gallery
		'gallery_enable'				=> true,
		'gallery_title'					=> esc_html__( 'Showcase Of Memory', 'elead-pro' ),
		'gallery_sub_title'				=> esc_html__( 'Our Gallery', 'elead-pro' ),
		'gallery_content_type'			=> 'demo',
		'gallery_btn_label'				=> esc_html__( 'View All Photos', 'elead-pro' ),
		'gallery_btn_link'				=> '#',

		// testimonial
		'testimonial_enable'			=> true,	
		'testimonial_title'				=> esc_html__( 'Testimonials', 'elead-pro' ),	
		'testimonial_sub_title'			=> esc_html__( 'What others think of us', 'elead-pro' ),	
		'testimonial_content_type'		=> 'demo',	
		'no_of_testimonial'				=> 3,

		// subscribe
		'subscribe_enable'				=> true,
		'subscribe_title'				=> esc_html__( 'Get Notified', 'elead-pro' ),
		'subscribe_sub_title'			=> esc_html__( 'Subscribe Newsletter', 'elead-pro' ),
		'subscribe_btn_label'			=> esc_html__( 'Subscribe', 'elead-pro' ),
		'subscribe_success_message'		=> esc_html__( 'Success! An email was just sent to confirm your subscription. Please find the email now and click ( Confirm Follow ) to start subscribing.', 'elead-pro' ),
		'subscribe_image'				=> get_template_directory_uri() . '/assets/uploads/subscribe-bg.jpg',
		'subscribe_logo'				=> get_template_directory_uri() . '/assets/uploads/subscribe-logo.png',

		// social
		'social_enable'					=> true,
		'social_entire_site_enable'		=> false,
		'social_title_link_1'			=> esc_url( 'http://facebook.com' ),
		'social_title_link_2'			=> esc_url( 'http://twitter.com' ),
		'social_title_link_3'			=> esc_url( 'http://instagram.com' ),
		'social_title_link_4'			=> esc_url( 'http://plus.google.com' ),
		'social_title_link_5'			=> esc_url( 'http://pinterest.com' ),

		// contact us template
		'contact_map_enable'			=> true,
		'map_content_type'				=> 'shortcode',
		'contact_us_title'				=> esc_html__( 'Get In Touch', 'elead-pro' ),
		'contact_us_subtitle'			=> esc_html__( 'Join Us', 'elead-pro' ),
		'contact_us_address'			=> esc_html__( 'Jawalkhel, Lalitpur, Nepal', 'elead-pro' ),
		'contact_us_phone'				=> esc_html__( '+ 123456789', 'elead-pro' ),
		'contact_us_email'				=> 'info@learnable.com',
		'contact_social_link_1'			=> esc_url( 'http://facebook.com' ),
		'contact_social_link_2'			=> esc_url( 'http://twitter.com' ),
		'contact_social_link_3'			=> esc_url( 'http://instagram.com' ),
		'contact_social_link_4'			=> esc_url( 'http://plus.google.com' ),
		'contact_social_link_5'			=> esc_url( 'http://pinterest.com' ),

		// gallery template
		'gallery_template_type'			=> 'category',
		'gallery_template_title'		=> esc_html__( 'Showcase of Memory', 'elead-pro' ),
		'gallery_template_subtitle'		=> esc_html__( 'Our Gallery', 'elead-pro' ),

		// services template
		'core_service_content_type'		=> 'custom',
		'core_service_enable'			=> true,
		'core_service_title'			=> esc_html__( 'Core Services', 'elead-pro' ),
		'core_service_image'			=> get_template_directory_uri() . '/assets/uploads/core-service.jpg',
		'goal_section_enable'			=> true,
		'goal_service_title'			=> esc_html__( 'Our Goal', 'elead-pro' ),
		'goal_service_image'			=> get_template_directory_uri() . '/assets/uploads/our-goal.jpg',
		'goal_content_type'				=> 'custom',
		'quality_service_enable'		=> true,
		'quality_service_content_type'	=> 'custom',
		'quality_service_count'			=> 6,
		'quality_service_title'			=> esc_html__( 'Why Choose Us', 'elead-pro' ),
		'quality_service_sub_title'		=> esc_html__( 'Our Quality Services', 'elead-pro' ),
		
		// Study Abroad Template
		'destination_enable'			=> true,
		'destination_content_type'		=> 'custom',
		'destination_custom_btn_label'	=> esc_html__( 'View All Destinations', 'elead-pro' ),
		'destination_custom_btn_url'	=> '#',
		'study_abroad_destination_count'=> 3,
		'study_guide_enable'			=> true,
		'study_guide_content_type'		=> 'custom',
		'study_guide_count'				=> 6,
		'study_guide_title'				=> esc_html__( 'Abroad Study Guide', 'elead-pro' ),
		'study_guide_sub_title'			=> esc_html__( 'Tools & Resources', 'elead-pro' ),

		// about us template
		'about_advert_title'			=> esc_html__( 'We are educational temple','elead-pro' ),
		'about_advert_btn_label'		=> esc_html__( 'Send Message','elead-pro' ),
		'about_advert_url'				=> esc_html__( '#','elead-pro' ),
		//message
		'message_enable'				=> true,
		'message_content_type'			=> 'custom',
		'message_section_title'			=> esc_html__( 'We provide best education in better way.', 'elead-pro' ),
		'message_title'					=> esc_html__( 'Linda Anderson', 'elead-pro' ),
		'message_sub_title'				=> esc_html__( 'The Principle', 'elead-pro' ),
		'message_description'			=> esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam efficitur tortor vel gravida egestas. Sed nec ligula pharetra, porta sem a, dapibus ipsum. Pellentesque facilisis facilisis interdum. Quisque faucibus enim arcu. Duis vitae turpis sed tortor mattis laoreet. Suspendisse non mi a nunc pulvinar bibendum., Learnable Education College', 'elead-pro' ),
		'message_link'					=> '#',
		'message_image'					=> get_template_directory_uri() . '/assets/uploads/bg-principals.jpg',
		//features
		'features_enable'				=> true,
		'features_content_type'			=> 'custom',		
		// team
		'aboutteam_enable'				=> true,
		'aboutteam_section_title'		=> esc_html__( 'Professional Teachers', 'elead-pro' ),
		'aboutteam_section_subtitle'	=> esc_html__( 'Our Qualified Manpower', 'elead-pro' ),
		'aboutteam_section_excerpt'		=> esc_html__( 'Pellentesque dui lectus, elementum non consectetur sed, lobortis sed dui. Ut facilisis metus eu vulputate fermentum. Phasellus nulla velit, lobortis ac faucibus id, maximus eu sapien.', 'elead-pro' ),
		'aboutteam_content_type'		=> 'custom',
		'aboutteam_custom_btn_label'	=> esc_html__( 'View All Teachers', 'elead-pro' ),
		'aboutteam_custom_btn_url'		=> esc_html__( '#', 'elead-pro' ),

	);

	$output = apply_filters( 'elead_pro_default_theme_options', $elead_pro_default_options );
	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}