<?php
/**
 * Counter Section options
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */

$wp_customize->add_section( 'elead_pro_counter', array(
	'title'             => esc_html__( 'Counter','elead-pro' ),
	'description'       => esc_html__( 'Counter Section Options.', 'elead-pro' ),
	'panel'             => 'elead_pro_sections_panel',
) );

// counter section enable setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[counter_enable]', array(
	'sanitize_callback'	=> 'elead_pro_sanitize_checkbox',
	'default'          	=> $options['counter_enable'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[counter_enable]', array(
	'label'            	=> esc_html__( 'Enable Counter Section', 'elead-pro' ),
	'section'          	=> 'elead_pro_counter',
	'type'             	=> 'checkbox',
) );

// counter section background setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[counter_image]', array(
	'sanitize_callback' => 'elead_pro_sanitize_image'
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'elead_pro_theme_options[counter_image]',
		array(
		'label'       		=> esc_html__( 'Select Background Image', 'elead-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'elead-pro' ), 1500, 1000 ),
		'section'     		=> 'elead_pro_counter',
		'active_callback'	=> 'elead_pro_is_counter_enable',
) ) );


for ( $i = 1; $i <= 4; $i++ ) :
	//  hr setting and control
	$wp_customize->add_setting( 'elead_pro_theme_options[counter_hr_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Elead_Pro_Customize_Horizontal_Line( $wp_customize, 'elead_pro_theme_options[counter_hr_' . $i . ']',
		array(
			'section'         => 'elead_pro_counter',
			'active_callback' => 'elead_pro_is_counter_enable',
			'type'			  => 'hr'
	) ) );

	// counter Section icon setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[counter_icon_' . $i . ']', array(
		'sanitize_callback'	=> 'sanitize_text_field',
		'default'          	=> $options['counter_icon_' . $i],
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[counter_icon_' . $i . ']', array(
		'label'            	=> sprintf( esc_html__( 'Icon %d', 'elead-pro' ), $i ),
		'description'     		=> sprintf( esc_html__( 'Use font awesome icon: Eg: %1$s. %2$s See more here %3$s', 'elead-pro' ), 'fa-users', '<a href="' . esc_url( 'http://fontawesome.io/icons/' ) . '" target="_blank">', '</a>' ),
		'section'          	=> 'elead_pro_counter',
		'type'             	=> 'text',
		'active_callback'	=> 'elead_pro_is_counter_enable',
	) );

	// counter Section count setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[counter_count_' . $i . ']', array(
		'sanitize_callback'	=> 'absint',
		'default'          	=> $options['counter_count_' . $i],
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[counter_count_' . $i . ']', array(
		'label'            	=> sprintf( esc_html__( 'Number Value %d', 'elead-pro' ), $i ),
		'section'          	=> 'elead_pro_counter',
		'type'             	=> 'number',
		'input_attrs'	=> array(
			'style'	=> 'width:100px',
			),
		'active_callback'	=> 'elead_pro_is_counter_enable',
	) );

	// counter Section title setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[counter_title_' . $i . ']', array(
		'sanitize_callback'	=> 'sanitize_text_field',
		'default'          	=> $options['counter_title_' . $i],
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[counter_title_' . $i . ']', array(
		'label'            	=> sprintf( esc_html__( 'Title %d', 'elead-pro' ), $i ),
		'section'          	=> 'elead_pro_counter',
		'type'             	=> 'text',
		'active_callback'	=> 'elead_pro_is_counter_enable',
	) );
endfor;