<?php
/**
 * Headline Section options
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */

$wp_customize->add_section( 'elead_pro_headline', array(
	'title'             => esc_html__( 'Headline','elead-pro' ),
	'description'       => esc_html__( 'Headline Section Options.', 'elead-pro' ),
	'panel'             => 'elead_pro_sections_panel',
) );

// Headline Section enable setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[headline_enable]', array(
	'sanitize_callback'	=> 'elead_pro_sanitize_checkbox',
	'default'          	=> $options['headline_enable'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[headline_enable]', array(
	'label'            	=> esc_html__( 'Enable Headline Section', 'elead-pro' ),
	'section'          	=> 'elead_pro_headline',
	'type'             	=> 'checkbox',
) );

// Headline Section label setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[headline_label]', array(
	'default'          	=> $options['headline_label'],
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( 'elead_pro_theme_options[headline_label]', array(
	'label'            	=> esc_html__( 'Headline Label', 'elead-pro' ),
	'section'          	=> 'elead_pro_headline',
	'type'             	=> 'text',
	'active_callback'	=> 'elead_pro_is_headline_enable',
) );

// Headline Section content type setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[headline_content_type]', array(
	'default'          	=> $options['headline_content_type'],
	'sanitize_callback'	=> 'elead_pro_sanitize_select',
) );

$wp_customize->add_control( 'elead_pro_theme_options[headline_content_type]', array(
	'label'            	=> esc_html__( 'Headline Content Type', 'elead-pro' ),
	'section'          	=> 'elead_pro_headline',
	'type'             	=> 'select',
	'active_callback'	=> 'elead_pro_is_headline_enable',
	'choices'			=> elead_pro_headline_options(),
) );

// Headline Section content type post setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[headline_content_post]', array(
	'sanitize_callback' => 'elead_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'elead_pro_theme_options[headline_content_post]', array(
	'active_callback'	=> 'elead_pro_headline_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'elead-pro' ),
	'description'       => esc_html__( 'Simply hover post title on dashboard to see the Post ID. ie: 11, 24, 34', 'elead-pro' ),
	'section'           => 'elead_pro_headline',
	'type'				=> 'text'
) );

// Headline Section content count setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[headline_content_count]', array(
	'default'			=> $options['headline_content_count'],
	'sanitize_callback' => 'elead_pro_sanitize_number_range',
	'validate_callback' => 'elead_pro_validate_headline_content_count',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'elead_pro_theme_options[headline_content_count]', array(
	'active_callback'	=> 'elead_pro_headline_content_category',
	'label'             => esc_html__( 'No. of Posts', 'elead-pro' ),
	'description'       => esc_html__( 'Max no of posts: 10. Please input the valid number and save. Then refresh the page to see the change.', 'elead-pro' ),
	'section'           => 'elead_pro_headline',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style'	=> 'width:100px',
		),
) );

// Headline Section content type category setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[headline_content_category]', array(
	'sanitize_callback' => 'elead_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Elead_Pro_Dropdown_Single_Category_Control( $wp_customize, 'elead_pro_theme_options[headline_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'elead-pro' ),
	'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'elead-pro' ),
	'section'         => 'elead_pro_headline',
	'type'			  => 'dropdown-category',
	'active_callback' => 'elead_pro_headline_content_category',
) ) );

// Headline Section custom post hr setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[headline_custom_hr_line]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Elead_Pro_Customize_Horizontal_Line( $wp_customize, 'elead_pro_theme_options[headline_custom_hr_line]',
	array(
		'section'         => 'elead_pro_headline',
		'active_callback' => 'elead_pro_is_headline_enable',
		'type'			  => 'hr'
) ) );

// Headline Section custom note
$wp_customize->add_setting( 'elead_pro_theme_options[headline_custom_note]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( new Elead_Pro_Note_Control( $wp_customize, 'elead_pro_theme_options[headline_custom_note]', array(
	'label'           	=> esc_html__( 'Social Link Value For Headline ', 'elead-pro' ),
	'section'         	=> 'elead_pro_headline',
	'active_callback' 	=> 'elead_pro_is_headline_enable',
	'type'            	=> 'description',
) ) );

// Headline social Section enable setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[headline_social_enable]', array(
	'sanitize_callback'	=> 'elead_pro_sanitize_checkbox',
	'default'          	=> $options['headline_social_enable'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[headline_social_enable]', array(
	'label'            	=> esc_html__( 'Enable Social Icon', 'elead-pro' ),
	'section'          	=> 'elead_pro_headline',
	'active_callback' 	=> 'elead_pro_is_headline_enable',
	'type'             	=> 'checkbox',
) );

for ( $i = 1; $i <= 5; $i++ ) :
	// Headline Section social title setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[headline_social_link_' . $i . ']', array(
		'sanitize_callback'	=> 'esc_url_raw',
		'default'          	=> $options['headline_social_link_' . $i],
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[headline_social_link_' . $i . ']', array(
		'label'            	=> sprintf( esc_html__( 'Social Link %d', 'elead-pro' ), $i ),
		'section'          	=> 'elead_pro_headline',
		'active_callback' 	=> 'elead_pro_is_social_headline_enable',
		'type'             	=> 'url',
		'input_attrs'	=> array(
			'placeholder'	=> esc_attr__( 'http://facebook.com', 'elead-pro' ),
			),
	) );
endfor;