<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function elead_pro_body_classes( $classes ) {
	$options = elead_pro_get_theme_options();

	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Add a class for typography
	$typography = (  $options['theme_typography'] == 'default' ) ? '' :  $options['theme_typography'];
	$classes[] = esc_attr( $typography );

	$body_typography = (  $options['body_theme_typography'] == 'default' ) ? '' :  $options['body_theme_typography'];
	$classes[] = esc_attr( $body_typography );

	// Add a class for layout
	$classes[] = esc_attr( $options['site_layout'] );

	// Add a class for sidebar
	$sidebar_position = elead_pro_layout();

	if ( is_singular() ) {
		$selected_sidebar = get_post_meta( get_the_id(), 'elead-pro-selected-sidebar', true );
		$post_sidebar = ! empty( $selected_sidebar ) ? $selected_sidebar : 'sidebar-1';
	} else {
		$post_sidebar = 'sidebar-1';
	}

	if ( is_active_sidebar( $post_sidebar ) ) {
		$classes[] = esc_attr( $sidebar_position );
	} else {
		$classes[] = 'no-sidebar';
	}

	return $classes;
}
add_filter( 'body_class', 'elead_pro_body_classes' );


if ( ! function_exists( 'elead_pro_inline_css' ) ) :
	/**
	 * Custom Header Codes
	 *
	 * @since Elead Pro 1.0
	 *
	 */
	function elead_pro_inline_css() {
		$options = elead_pro_get_theme_options();
		$css = '';

		$pagination_type = isset( $options['pagination_type'] ) ? $options['pagination_type'] : 'default';
		if ( $pagination_type == 'infinite' ) {
			$css .= '
			.site-main nav.pagination.navigation {
				display:none;
			}';
		}

		wp_add_inline_style( 'elead-pro-style', $css );
	}
endif;
add_action( 'wp_enqueue_scripts', 'elead_pro_inline_css', 20 );